@@ -238,7 +238,7 @@ jobs:\n",
             // job steps
             conf.push_str(
                 "    steps:
-      - uses: actions/checkout@v3\n",
+      - uses: actions/checkout@v4\n",
             );
 
             // install pyodide-build for emscripten
@@ -261,7 +261,7 @@ jobs:\n",
           actions-cache-folder: emsdk-cache\n",
                 );
                 conf.push_str(
-                    "      - uses: actions/setup-python@v4
+                    "      - uses: actions/setup-python@v5
         with:
           python-version: ${{ env.PYTHON_VERSION }}\n",
                 );
@@ -271,7 +271,7 @@ jobs:\n",
                 // setup python on demand
                 if setup_python {
                     conf.push_str(
-                        "      - uses: actions/setup-python@v4
+                        "      - uses: actions/setup-python@v5
         with:
           python-version: '3.10'\n",
                     );
@@ -324,13 +324,13 @@ jobs:\n",
             }
             // upload wheels
             let artifact_name = if matches!(platform, Platform::Emscripten) {
-                "wasm-wheels"
+                String::from("wasm-wheels")
             } else {
-                "wheels"
+                format!("wheels-{platform}-${{{{ matrix.target }}}}")
             };
             conf.push_str(&format!(
                 "      - name: Upload wheels
-        uses: actions/upload-artifact@v3
+        uses: actions/upload-artifact@v4
         with:
           name: {artifact_name}
           path: dist
@@ -432,7 +432,7 @@ jobs:\n",
                 r#"  sdist:
     runs-on: ubuntu-latest
     steps:
-      - uses: actions/checkout@v3
+      - uses: actions/checkout@v4
       - name: Build sdist
         uses: PyO3/maturin-action@v1
         with:
@@ -442,9 +442,9 @@ jobs:\n",
             ));
             conf.push_str(
                 "      - name: Upload sdist
-        uses: actions/upload-artifact@v3
+        uses: actions/upload-artifact@v4
         with:
-          name: wheels
+          name: wheels-sdist
           path: dist
 ",
             );
@@ -470,29 +470,23 @@ jobs:\n",
         }
         conf.push_str(
             r#"    steps:
-      - uses: actions/download-artifact@v3
-        with:
-          name: wheels
+      - uses: actions/download-artifact@v4
       - name: Publish to PyPI
         uses: PyO3/maturin-action@v1
         env:
           MATURIN_PYPI_TOKEN: ${{ secrets.PYPI_API_TOKEN }}
         with:
           command: upload
-          args: --non-interactive --skip-existing *
+          args: --non-interactive --skip-existing wheels-*/*
 "#,
         );
         if platforms.contains(&Platform::Emscripten) {
             conf.push_str(
-                "      - uses: actions/download-artifact@v3
-        with:
-          name: wasm-wheels
-          path: wasm
-      - name: Upload to GitHub Release
+                "      - name: Upload to GitHub Release
         uses: softprops/action-gh-release@v1
         with:
           files: |
-            wasm/*.whl
+            wasm-wheels/*.whl
           prerelease: ${{ contains(github.ref, 'alpha') || contains(github.ref, 'beta') }}
 ",
             );
@@ -514,8 +508,7 @@ jobs:\n",
 mod tests {
     use super::GenerateCI;
     use crate::BridgeModel;
-    use indoc::indoc;
-    use pretty_assertions::assert_eq;
+    use expect_test::expect;
 
     #[test]
     fn test_generate_github() {
@@ -530,7 +523,7 @@ mod tests {
             .skip(5)
             .collect::<Vec<_>>()
             .join("\n");
-        let expected = indoc! {r#"
+        let expected = expect![[r#"
             name: CI
 
             on:
@@ -553,8 +546,8 @@ mod tests {
                   matrix:
                     target: [x86_64, x86, aarch64, armv7, s390x, ppc64le]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                   - name: Build wheels
@@ -565,9 +558,9 @@ mod tests {
                       sccache: 'true'
                       manylinux: auto
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-linux-${{ matrix.target }}
                       path: dist
 
               windows:
@@ -576,8 +569,8 @@ mod tests {
                   matrix:
                     target: [x64, x86]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                       architecture: ${{ matrix.target }}
@@ -588,9 +581,9 @@ mod tests {
                       args: --release --out dist --find-interpreter
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-windows-${{ matrix.target }}
                       path: dist
 
               macos:
@@ -599,8 +592,8 @@ mod tests {
                   matrix:
                     target: [x86_64, aarch64]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                   - name: Build wheels
@@ -610,24 +603,24 @@ mod tests {
                       args: --release --out dist --find-interpreter
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-macos-${{ matrix.target }}
                       path: dist
 
               sdist:
                 runs-on: ubuntu-latest
                 steps:
-                  - uses: actions/checkout@v3
+                  - uses: actions/checkout@v4
                   - name: Build sdist
                     uses: PyO3/maturin-action@v1
                     with:
                       command: sdist
                       args: --out dist
                   - name: Upload sdist
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-sdist
                       path: dist
 
               release:
@@ -636,18 +629,15 @@ mod tests {
                 if: "startsWith(github.ref, 'refs/tags/')"
                 needs: [linux, windows, macos, sdist]
                 steps:
-                  - uses: actions/download-artifact@v3
-                    with:
-                      name: wheels
+                  - uses: actions/download-artifact@v4
                   - name: Publish to PyPI
                     uses: PyO3/maturin-action@v1
                     env:
                       MATURIN_PYPI_TOKEN: ${{ secrets.PYPI_API_TOKEN }}
                     with:
                       command: upload
-                      args: --non-interactive --skip-existing *
-        "#};
-        assert_eq!(conf, expected.trim());
+                      args: --non-interactive --skip-existing wheels-*/*"#]];
+        expected.assert_eq(&conf);
     }
 
     #[test]
@@ -659,7 +649,7 @@ mod tests {
             .skip(5)
             .collect::<Vec<_>>()
             .join("\n");
-        let expected = indoc! {r#"
+        let expected = expect![[r#"
             name: CI
 
             on:
@@ -682,8 +672,8 @@ mod tests {
                   matrix:
                     target: [x86_64, x86, aarch64, armv7, s390x, ppc64le]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                   - name: Build wheels
@@ -694,9 +684,9 @@ mod tests {
                       sccache: 'true'
                       manylinux: auto
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-linux-${{ matrix.target }}
                       path: dist
 
               windows:
@@ -705,8 +695,8 @@ mod tests {
                   matrix:
                     target: [x64, x86]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                       architecture: ${{ matrix.target }}
@@ -717,9 +707,9 @@ mod tests {
                       args: --release --out dist
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-windows-${{ matrix.target }}
                       path: dist
 
               macos:
@@ -728,8 +718,8 @@ mod tests {
                   matrix:
                     target: [x86_64, aarch64]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                   - name: Build wheels
@@ -739,9 +729,9 @@ mod tests {
                       args: --release --out dist
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-macos-${{ matrix.target }}
                       path: dist
 
               release:
@@ -750,18 +740,15 @@ mod tests {
                 if: "startsWith(github.ref, 'refs/tags/')"
                 needs: [linux, windows, macos]
                 steps:
-                  - uses: actions/download-artifact@v3
-                    with:
-                      name: wheels
+                  - uses: actions/download-artifact@v4
                   - name: Publish to PyPI
                     uses: PyO3/maturin-action@v1
                     env:
                       MATURIN_PYPI_TOKEN: ${{ secrets.PYPI_API_TOKEN }}
                     with:
                       command: upload
-                      args: --non-interactive --skip-existing *
-        "#};
-        assert_eq!(conf, expected.trim());
+                      args: --non-interactive --skip-existing wheels-*/*"#]];
+        expected.assert_eq(&conf);
     }
 
     #[test]
@@ -782,7 +769,7 @@ mod tests {
             .skip(5)
             .collect::<Vec<_>>()
             .join("\n");
-        let expected = indoc! {r#"
+        let expected = expect![[r#"
             name: CI
 
             on:
@@ -805,8 +792,8 @@ mod tests {
                   matrix:
                     target: [x86_64, x86, aarch64, armv7, s390x, ppc64le]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                   - name: Build wheels
@@ -817,9 +804,9 @@ mod tests {
                       sccache: 'true'
                       manylinux: auto
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-linux-${{ matrix.target }}
                       path: dist
                   - name: pytest
                     if: ${{ startsWith(matrix.target, 'x86_64') }}
@@ -851,8 +838,8 @@ mod tests {
                   matrix:
                     target: [x64, x86]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                       architecture: ${{ matrix.target }}
@@ -863,9 +850,9 @@ mod tests {
                       args: --release --out dist --find-interpreter
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-windows-${{ matrix.target }}
                       path: dist
                   - name: pytest
                     if: ${{ !startsWith(matrix.target, 'aarch64') }}
@@ -882,8 +869,8 @@ mod tests {
                   matrix:
                     target: [x86_64, aarch64]
                 steps:
-                  - uses: actions/checkout@v3
-                  - uses: actions/setup-python@v4
+                  - uses: actions/checkout@v4
+                  - uses: actions/setup-python@v5
                     with:
                       python-version: '3.10'
                   - name: Build wheels
@@ -893,9 +880,9 @@ mod tests {
                       args: --release --out dist --find-interpreter
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-macos-${{ matrix.target }}
                       path: dist
                   - name: pytest
                     if: ${{ !startsWith(matrix.target, 'aarch64') }}
@@ -909,16 +896,16 @@ mod tests {
               sdist:
                 runs-on: ubuntu-latest
                 steps:
-                  - uses: actions/checkout@v3
+                  - uses: actions/checkout@v4
                   - name: Build sdist
                     uses: PyO3/maturin-action@v1
                     with:
                       command: sdist
                       args: --out dist
                   - name: Upload sdist
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-sdist
                       path: dist
 
               release:
@@ -927,18 +914,15 @@ mod tests {
                 if: "startsWith(github.ref, 'refs/tags/')"
                 needs: [linux, windows, macos, sdist]
                 steps:
-                  - uses: actions/download-artifact@v3
-                    with:
-                      name: wheels
+                  - uses: actions/download-artifact@v4
                   - name: Publish to PyPI
                     uses: PyO3/maturin-action@v1
                     env:
                       MATURIN_PYPI_TOKEN: ${{ secrets.PYPI_API_TOKEN }}
                     with:
                       command: upload
-                      args: --non-interactive --skip-existing *
-        "#};
-        assert_eq!(conf, expected.trim());
+                      args: --non-interactive --skip-existing wheels-*/*"#]];
+        expected.assert_eq(&conf);
     }
 
     #[test]
@@ -950,7 +934,7 @@ mod tests {
             .skip(5)
             .collect::<Vec<_>>()
             .join("\n");
-        let expected = indoc! {r#"
+        let expected = expect![[r#"
             name: CI
 
             on:
@@ -973,7 +957,7 @@ mod tests {
                   matrix:
                     target: [x86_64, x86, aarch64, armv7, s390x, ppc64le]
                 steps:
-                  - uses: actions/checkout@v3
+                  - uses: actions/checkout@v4
                   - name: Build wheels
                     uses: PyO3/maturin-action@v1
                     with:
@@ -982,9 +966,9 @@ mod tests {
                       sccache: 'true'
                       manylinux: auto
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-linux-${{ matrix.target }}
                       path: dist
 
               windows:
@@ -993,7 +977,7 @@ mod tests {
                   matrix:
                     target: [x64, x86]
                 steps:
-                  - uses: actions/checkout@v3
+                  - uses: actions/checkout@v4
                   - name: Build wheels
                     uses: PyO3/maturin-action@v1
                     with:
@@ -1001,9 +985,9 @@ mod tests {
                       args: --release --out dist
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-windows-${{ matrix.target }}
                       path: dist
 
               macos:
@@ -1012,7 +996,7 @@ mod tests {
                   matrix:
                     target: [x86_64, aarch64]
                 steps:
-                  - uses: actions/checkout@v3
+                  - uses: actions/checkout@v4
                   - name: Build wheels
                     uses: PyO3/maturin-action@v1
                     with:
@@ -1020,24 +1004,24 @@ mod tests {
                       args: --release --out dist
                       sccache: 'true'
                   - name: Upload wheels
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-macos-${{ matrix.target }}
                       path: dist
 
               sdist:
                 runs-on: ubuntu-latest
                 steps:
-                  - uses: actions/checkout@v3
+                  - uses: actions/checkout@v4
                   - name: Build sdist
                     uses: PyO3/maturin-action@v1
                     with:
                       command: sdist
                       args: --out dist
                   - name: Upload sdist
-                    uses: actions/upload-artifact@v3
+                    uses: actions/upload-artifact@v4
                     with:
-                      name: wheels
+                      name: wheels-sdist
                       path: dist
 
               release:
@@ -1046,17 +1030,14 @@ mod tests {
                 if: "startsWith(github.ref, 'refs/tags/')"
                 needs: [linux, windows, macos, sdist]
                 steps:
-                  - uses: actions/download-artifact@v3
-                    with:
-                      name: wheels
+                  - uses: actions/download-artifact@v4
                   - name: Publish to PyPI
                     uses: PyO3/maturin-action@v1
                     env:
                       MATURIN_PYPI_TOKEN: ${{ secrets.PYPI_API_TOKEN }}
                     with:
                       command: upload
-                      args: --non-interactive --skip-existing *
-        "#};
-        assert_eq!(conf, expected.trim());
+                      args: --non-interactive --skip-existing wheels-*/*"#]];
+        expected.assert_eq(&conf);
     }
 }
