@@ -30,7 +30,7 @@ use tracing::debug;
     after_help = "Visit https://maturin.rs to learn more about maturin.",
     styles = cargo_options::styles(),
 )]
-#[cfg_attr(feature = "cargo-clippy", allow(clippy::large_enum_variant))]
+#[cfg_attr(clippy, allow(clippy::large_enum_variant))]
 /// Build and publish crates with pyo3, rust-cpython and cffi bindings as well
 /// as rust binaries as python packages
 enum Opt {
@@ -191,6 +191,7 @@ fn detect_venv(target: &Target) -> Result<PathBuf> {
     match (env::var_os("VIRTUAL_ENV"), env::var_os("CONDA_PREFIX")) {
         (Some(dir), None) => return Ok(PathBuf::from(dir)),
         (None, Some(dir)) => return Ok(PathBuf::from(dir)),
+        (Some(venv), Some(conda)) if venv == conda => return Ok(PathBuf::from(venv)),
         (Some(_), Some(_)) => {
             bail!("Both VIRTUAL_ENV and CONDA_PREFIX are set. Please unset one of them")
         }
@@ -261,8 +262,8 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
             };
 
             let mut writer = PathWriter::from_path(metadata_directory);
-            write_dist_info(&mut writer, &context.metadata21, &tags)?;
-            println!("{}", context.metadata21.get_dist_info_dir().display());
+            write_dist_info(&mut writer, &context.metadata23, &tags)?;
+            println!("{}", context.metadata23.get_dist_info_dir().display());
         }
         Pep517Command::BuildWheel {
             build_options,
