@@ -16,22 +16,23 @@ use std::str::FromStr;
 /// The metadata required to generate the .dist-info directory
 #[derive(Serialize, Deserialize, Debug, Clone, Eq, PartialEq)]
 pub struct WheelMetadata {
-    /// Python Package Metadata 2.1
-    pub metadata21: Metadata21,
+    /// Python Package Metadata 2.3
+    pub metadata23: Metadata23,
     /// The `[console_scripts]` for the entry_points.txt
     pub scripts: HashMap<String, String>,
     /// The name of the module can be distinct from the package name, mostly
     /// because package names normally contain minuses while module names
-    /// have underscores. The package name is part of metadata21
+    /// have underscores. The package name is part of metadata23
     pub module_name: String,
 }
 
-/// Python Package Metadata 2.1 as specified in
+/// Python Package Metadata 2.3 as specified in
 /// https://packaging.python.org/specifications/core-metadata/
+/// Maturin writes static metadata and does not support dynamic fields atm.
 #[derive(Serialize, Deserialize, Debug, Clone, Eq, PartialEq)]
 #[serde(rename_all = "kebab-case")]
 #[allow(missing_docs)]
-pub struct Metadata21 {
+pub struct Metadata23 {
     // Mandatory fields
     pub metadata_version: String,
     pub name: String,
@@ -65,11 +66,11 @@ pub struct Metadata21 {
     pub entry_points: IndexMap<String, IndexMap<String, String>>,
 }
 
-impl Metadata21 {
+impl Metadata23 {
     /// Initializes with name, version and otherwise the defaults
     pub fn new(name: String, version: Version) -> Self {
         Self {
-            metadata_version: "2.1".to_string(),
+            metadata_version: "2.3".to_string(),
             name,
             version,
             platform: vec![],
@@ -122,7 +123,7 @@ fn path_to_content_type(path: &Path) -> String {
         })
 }
 
-impl Metadata21 {
+impl Metadata23 {
     /// Merge metadata with pyproject.toml, where pyproject.toml takes precedence
     ///
     /// pyproject_dir must be the directory containing pyproject.toml
@@ -211,6 +212,9 @@ impl Metadata21 {
                     glob::glob(&escaped_manifest_path.join(pattern).to_string_lossy())?
                         .filter_map(Result::ok)
                 {
+                    if !license_path.is_file() {
+                        continue;
+                    }
                     // if the pyproject.toml specified the license file,
                     // then we won't list it as automatically included
                     if !self.license_files.contains(&license_path) {
@@ -334,7 +338,7 @@ impl Metadata21 {
     pub fn from_cargo_toml(
         manifest_path: impl AsRef<Path>,
         cargo_metadata: &cargo_metadata::Metadata,
-    ) -> Result<Metadata21> {
+    ) -> Result<Metadata23> {
         let package = cargo_metadata
             .root_package()
             .context("Expected cargo to return metadata with root_package")?;
@@ -397,8 +401,8 @@ impl Metadata21 {
                 err
             )
         })?;
-        let metadata = Metadata21 {
-            // name, version and metadata_version are added through Metadata21::new()
+        let metadata = Metadata23 {
+            // name, version and metadata_version are added through metadata23::new()
             // Mapped from cargo metadata
             summary: package.description.clone(),
             description,
@@ -420,7 +424,7 @@ impl Metadata21 {
             license: package.license.clone(),
             license_files,
             project_url,
-            ..Metadata21::new(name, version)
+            ..Metadata23::new(name, version)
         };
         Ok(metadata)
     }
@@ -607,7 +611,7 @@ mod test {
         readme: &str,
         cargo_toml: &str,
         expected: Expect,
-    ) -> Metadata21 {
+    ) -> Metadata23 {
         let crate_dir = tempfile::tempdir().unwrap();
         let crate_path = crate_dir.path();
         let manifest_path = crate_path.join("Cargo.toml");
@@ -631,7 +635,7 @@ mod test {
             .exec()
             .unwrap();
 
-        let metadata = Metadata21::from_cargo_toml(crate_path, &cargo_metadata).unwrap();
+        let metadata = Metadata23::from_cargo_toml(crate_path, &cargo_metadata).unwrap();
 
         let actual = metadata.to_file_contents().unwrap();
 
@@ -675,7 +679,7 @@ mod test {
         );
 
         let expected = expect![[r#"
-            Metadata-Version: 2.1
+            Metadata-Version: 2.3
             Name: info-project
             Version: 0.1.0
             Summary: A test project
@@ -723,7 +727,7 @@ mod test {
             .manifest_path(manifest_dir.join("Cargo.toml"))
             .exec()
             .unwrap();
-        let mut metadata = Metadata21::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
+        let mut metadata = Metadata23::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
         let pyproject_toml = PyProjectToml::new(manifest_dir.join("pyproject.toml")).unwrap();
         metadata
             .merge_pyproject_toml(&manifest_dir, &pyproject_toml)
@@ -772,7 +776,7 @@ mod test {
             .manifest_path(manifest_dir.join("Cargo.toml"))
             .exec()
             .unwrap();
-        let mut metadata = Metadata21::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
+        let mut metadata = Metadata23::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
         let pyproject_toml = PyProjectToml::new(manifest_dir.join("pyproject.toml")).unwrap();
         metadata
             .merge_pyproject_toml(&manifest_dir, &pyproject_toml)
@@ -793,7 +797,7 @@ mod test {
             .manifest_path(manifest_dir.join("Cargo.toml"))
             .exec()
             .unwrap();
-        let metadata = Metadata21::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
+        let metadata = Metadata23::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
         assert!(metadata.description.unwrap().starts_with("# pyo3-mixed"));
         assert_eq!(
             metadata.description_content_type.unwrap(),
@@ -808,7 +812,7 @@ mod test {
             .manifest_path(manifest_dir.join("Cargo.toml"))
             .exec()
             .unwrap();
-        let mut metadata = Metadata21::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
+        let mut metadata = Metadata23::from_cargo_toml(&manifest_dir, &cargo_metadata).unwrap();
         let pyproject_toml = PyProjectToml::new(manifest_dir.join("pyproject.toml")).unwrap();
         metadata
             .merge_pyproject_toml(&manifest_dir, &pyproject_toml)
