@@ -45,7 +45,7 @@ pub struct PublishOpt {
     /// Password for pypi or your custom registry.
     ///
     /// Can also be set via MATURIN_PASSWORD environment variable.
-    #[arg(short, long)]
+    #[arg(short, long, env = "MATURIN_PASSWORD", hide_env_values = true)]
     password: Option<String>,
     /// Continue uploading files if one already exists.
     /// (Only valid when uploading to PyPI. Other implementations may not support this.)
@@ -235,14 +235,13 @@ fn resolve_pypi_cred(
     }
 
     // fallback to username and password
-    if opt.non_interactive {
+    if opt.non_interactive && (opt.username.is_none() || opt.password.is_none()) {
         bail!("Credentials not found and non-interactive mode is enabled");
     }
     let username = opt.username.clone().unwrap_or_else(get_username);
     let password = opt
         .password
         .clone()
-        .or_else(|| env::var("MATURIN_PASSWORD").ok())
         .unwrap_or_else(|| get_password(&username));
     Ok((username, password))
 }
@@ -355,15 +354,6 @@ fn canonicalize_name(name: &str) -> String {
         .to_lowercase()
 }
 
-fn http_proxy() -> Result<String, env::VarError> {
-    env::var("HTTPS_PROXY")
-        .or_else(|_| env::var("https_proxy"))
-        .or_else(|_| env::var("HTTP_PROXY"))
-        .or_else(|_| env::var("http_proxy"))
-        .or_else(|_| env::var("ALL_PROXY"))
-        .or_else(|_| env::var("all_proxy"))
-}
-
 #[cfg(any(feature = "native-tls", feature = "rustls"))]
 fn tls_ca_bundle() -> Option<OsString> {
     env::var_os("MATURIN_CA_BUNDLE")
@@ -377,15 +367,12 @@ fn tls_ca_bundle() -> Option<OsString> {
 fn http_agent() -> Result<ureq::Agent, UploadError> {
     use std::sync::Arc;
 
-    let mut builder = ureq::builder();
-    if let Ok(proxy) = http_proxy() {
-        let proxy = ureq::Proxy::new(proxy)?;
-        builder = builder.proxy(proxy);
-    };
+    let mut builder = ureq::builder().try_proxy_from_env(true);
     let mut tls_builder = native_tls::TlsConnector::builder();
     if let Some(ca_bundle) = tls_ca_bundle() {
         let mut reader = io::BufReader::new(File::open(ca_bundle)?);
-        for cert in rustls_pemfile::certs(&mut reader)? {
+        for cert in rustls_pemfile::certs(&mut reader) {
+            let cert = cert?;
             tls_builder.add_root_certificate(native_tls::Certificate::from_pem(&cert)?);
         }
     }
@@ -398,18 +385,13 @@ fn http_agent() -> Result<ureq::Agent, UploadError> {
 fn http_agent() -> Result<ureq::Agent, UploadError> {
     use std::sync::Arc;
 
-    let mut builder = ureq::builder();
-    if let Ok(proxy) = http_proxy() {
-        let proxy = ureq::Proxy::new(proxy)?;
-        builder = builder.proxy(proxy);
-    };
+    let builder = ureq::builder().try_proxy_from_env(true);
     if let Some(ca_bundle) = tls_ca_bundle() {
         let mut reader = io::BufReader::new(File::open(ca_bundle)?);
-        let certs = rustls_pemfile::certs(&mut reader)?;
+        let certs = rustls_pemfile::certs(&mut reader).collect::<Result<Vec<_>, _>>()?;
         let mut root_certs = rustls::RootCertStore::empty();
-        root_certs.add_parsable_certificates(&certs);
+        root_certs.add_parsable_certificates(certs);
         let client_config = rustls::ClientConfig::builder()
-            .with_safe_defaults()
             .with_root_certificates(root_certs)
             .with_no_client_auth();
         Ok(builder.tls_config(Arc::new(client_config)).build())
@@ -421,11 +403,7 @@ fn http_agent() -> Result<ureq::Agent, UploadError> {
 #[cfg(not(any(feature = "native-tls", feature = "rustls")))]
 #[allow(clippy::result_large_err)]
 fn http_agent() -> Result<ureq::Agent, UploadError> {
-    let mut builder = ureq::builder();
-    if let Ok(proxy) = http_proxy() {
-        let proxy = ureq::Proxy::new(proxy)?;
-        builder = builder.proxy(proxy);
-    };
+    let builder = ureq::builder().try_proxy_from_env(true);
     Ok(builder.build())
 }
 
